Description Usage Format Source
This dataset comes from the Host Community Multi Sector Needs Assessment conducted in 2018 by IMPACT/REACH on behalf of the ISCG and funded by ECHO. This is the sample size per union used in both Ukhia and Teknaf.
1 |
A data frame with 11 rows and 7 variables:
Upazilacharacter COLUMN_DESCRIPTION
Unioncharacter COLUMN_DESCRIPTION
NbHHinteger COLUMN_DESCRIPTION
Populationinteger COLUMN_DESCRIPTION
EstPersPerShelterdouble COLUMN_DESCRIPTION
SSinteger COLUMN_DESCRIPTION
TotPtsinteger COLUMN_DESCRIPTION
http://somewhere.important.com/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.